@@ -5,7 +5,7 @@ use utf8;
 
 package Dist::Zilla::MetaProvides::Types;
 
-our $VERSION = '2.000003';
+our $VERSION = '2.000010';
 
 # ABSTRACT: Utility Types for the MetaProvides Plugin
 
@@ -61,7 +61,21 @@ Dist::Zilla::MetaProvides::Types - Utility Types for the MetaProvides Plugin
 
 =head1 VERSION
 
-version 2.000003
+version 2.000010
+
+=head1 QUICK REFERENCE
+
+  << ModVersion       # Str | Undef
+  << ProviderObject   # does Dist::Zilla::Role::MetaProvider::Provider
+
+=over 4
+
+=item * C<Role::MetaProvider::Provider> : L<<
+C<Dist::Zilla::Role::MetaProvider::Provider>
+|Dist::Zilla::Role::MetaProvider::Provider
+>>
+
+=back
 
 =head1 SUBTYPES
 
